//-----------------------------------------------------------------------------
// jondahli
//
// Phrase.java
//
// Contains entire phrase
//
// (c) 2011 Brandon Valosek
//-----------------------------------------------------------------------------

package com.bvalosek.jondahli.core;

// imports
import java.lang.String;
import java.util.List;
import java.util.ArrayList;
import android.util.Log;

class Phrase {
   
   // list of words that make up the phrase
   private List<Word> mWords = new ArrayList<Word> ();

   // links to other phrases that are response to this one
   private List<Phrase> mLinks  = new ArrayList<Phrase> ();

   /** create the phrase with a list of words */
   public Phrase (List<Word> words) {
      mWords = words;
   }

   /** add a linked phrase (reponse to this phrase) */
   public void addLink (Phrase p) {
   	mLinks.add (p);
   }

   /** get all linked phrases (all responses) */
   public List<Phrase> getLinks () {
      return mLinks;
   }
 
   /** get all the words */
   public List<Word> getWords () {
      return mWords;
   }

   /** get the content */
   public String getText () {
      // loop through all the words and cat them together
      String ret = "";
      int n = 0;
      for (Word w : mWords) {
         if (n++ > 0)
            ret += " ";

         ret += w.getText();
      }

      return ret;
   }
	
	/** spit out text */
	public String toString () {
		return getText ();
	}

   // constants used in scoring phrases
   private static final int COMMON_INC = 15;
   private static final float SAME_LENGTH_MULT = 3.5f;
   private static final float MIN_LENGTH_MULT = 0.2f;


   /** score this phrase against another to see how closely they match */
   public int getScore(Phrase p) {
      int ret = 0;

      // if this phrase has no good resposnes, penalize the score
      if (p.mLinks.size() < 1) {
      	return 1;
      }

      // add COMMON_INC for every word in common
      for (Word wa : mWords) {
         for (Word wb : p.getWords() ) {
            if (wa.equals(wb) ) {
            	ret += COMMON_INC;
            	break;
            }
         }
      }

      // get a mult for how close in length
      float sizeMult = SAME_LENGTH_MULT;
      int sizea = mWords.size ();
      int sizeb = p.getWords().size();
   
      if (sizea > sizeb) {
         sizeMult = (float)sizeb / sizea;
      } else if (sizeb > sizea) {
         sizeMult = (float)sizea / sizeb;
      }

      // limit
      if (sizeMult < MIN_LENGTH_MULT) {
      	sizeMult = MIN_LENGTH_MULT;
      }

      // combine
      ret = (int)(sizeMult * ret);

      // no zeros
      if (ret < 1)
      	ret = 1;

      // done
      return ret;
   }
}
