//-----------------------------------------------------------------------------
// jondahli
//
// ChatActivity.java
//
// Main convo view
//
// (c) 2011 Brandon Valosek
//-----------------------------------------------------------------------------

package com.bvalosek.jondahli.ui;


// my stuff
import com.bvalosek.jondahli.core.Dahli;
import com.bvalosek.jondahli.R;
import com.bvalosek.jondahli.core.ConvoEntry;
import com.bvalosek.jondahli.JonDahliApp;

// imports
import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.ListView;
import android.widget.LinearLayout;
import android.view.LayoutInflater;
import android.content.Context;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import java.util.ArrayList;
import java.util.List;
import android.widget.TextView;
import android.widget.EditText;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import java.io.InputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import android.util.Log;
import android.content.Intent;
import android.view.Gravity;


public class ChatActivity extends Activity
{
   /* views */
   private ListView     mUiConvoList = null;
   private EditText     mUiInputBox = null;

   /* app context to deal with state and other global shit */
   private JonDahliApp  mApp = null;
   
   /* adapter for the convo list */
   private ConvoListAdapter mConvoListAdapter = null;
   
   /** Called when the activity is first created. */
   @Override
   public void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);

      // inflate UI from XML
      setContentView(R.layout.chat_layout);

      // find views
      mUiConvoList = (ListView)findViewById (R.id.ui_convo_list);
      mUiInputBox = (EditText)findViewById (R.id.ui_input_box);

      // get app context
      mApp = (JonDahliApp)getApplicationContext ();

      // attach adapter
      mConvoListAdapter = new ConvoListAdapter(this);
      mUiConvoList.setAdapter(mConvoListAdapter);
   }

   /** called when we want to infalte the menu */
   @Override public boolean onCreateOptionsMenu (Menu menu) {
      // request inflater from activity and inflate into its menu
      MenuInflater inflater = getMenuInflater ();
      inflater.inflate (R.menu.home_menu, menu);

      // made it
      return true;
   }

   /** called to handle a menu event */
   @Override public boolean onOptionsItemSelected (MenuItem item) {
      // what it do mayne
      switch (item.getItemId () ) {
      /* pressed the load menu button */
      case R.id.menu_load:
         mApp.loadDefaults ();
         break;
      case R.id.menu_about:
         // create a new intent to display the about activity
         Intent i = new Intent ();
         i.setClassName ("com.bvalosek.jondahli",
            "com.bvalosek.jondahli.ui.AboutActivity");
         startActivity (i);

         break;
      }

      // made it
      return true;
   }

   /** called when the SEND button is pressed */
   public void onSendPress (View v) {
      // get text and clear input box
      String s = mUiInputBox.getText().toString();
      mUiInputBox.setText ("");

      // send jon the message
      mApp.getDahli().doResponse (s);

      // draw view
      mConvoListAdapter.notifyDataSetChanged ();
   }

   /** adapter for the convo list */
   private class ConvoListAdapter extends BaseAdapter {
      
      // keep track of our layout inflater
      private LayoutInflater mInflater;

      /** ctor when given a context to create our ladder infaltor in */
      public ConvoListAdapter (Context c) {
      	//m ake the inflator
      	mInflater = LayoutInflater.from(c);
      }

      /** number of elements */
      public int getCount() {
      	return mApp.getThread().size();
      }

      /** get from a position */
      public Object getItem(int pos) {
      	return mApp.getThread().get(pos);
      }

      /** get ID for a position */
      public long getItemId(int position) {
      	return position;
      }

      /** actually redner the view */
      public View getView(int pos, View convertView, ViewGroup parent) {
         LinearLayout theRow = null;

         // create the view of we need to for this row
         if (convertView == null) {
         	theRow = (LinearLayout)mInflater.inflate(
         	      R.layout.convo_row, parent, false);
         } else {
            theRow = (LinearLayout)convertView;         
         }

         // the convo piece
         ConvoEntry theEntry = mApp.getThread().get (pos);
         
         // map UI elements to objects
         TextView mainText = (TextView)theRow.findViewById(R.id.ui_maintext);

         // modify the row
         mainText.setText (theEntry.mContent);
        
         // sender text
         if (theEntry.mOrigin == 1) {
            // set background
            mainText.setBackgroundResource (R.drawable.bluebubble);       

            // flush it right
            LinearLayout.LayoutParams params =
               (LinearLayout.LayoutParams)mainText.getLayoutParams();
            params.gravity = Gravity.LEFT;
            mainText.setLayoutParams(params);
         } else {
            // set background
            mainText.setBackgroundResource (R.drawable.greybubble);       

            // flush it right
            LinearLayout.LayoutParams params =
               (LinearLayout.LayoutParams)mainText.getLayoutParams();
            params.gravity = Gravity.RIGHT;
            mainText.setLayoutParams(params);
         }

         // return the finished view
         return theRow; 
      }


   }
}
